@@ -27,8 +27,6 @@
 
 #include <QUrl>
 
-#include <QDateTime>
-
 class DownloadJob : public KJob
 {
     Q_OBJECT
@@ -62,6 +60,7 @@ protected:
 
 private:
     void updateDescription();
+    void saveOriginUrl();
 
     int m_id = -1;
 
@@ -74,7 +73,7 @@ private:
 
     QString m_mimeType;
 
-    QDateTime m_startTime;
-    QDateTime m_endTime;
+    // In doubt, assume incognito
+    bool m_incognito = true;
 
 };
