@@ -27,8 +27,11 @@
 #include <QDBusConnection>
 #include <QProcess>
 
+#include "pluginmanager.h"
 #include "settingsadaptor.h"
 
+#include <config-host.h>
+
 const QMap<Settings::Environment, QString> Settings::environmentNames = {
     {Settings::Environment::Chrome, QStringLiteral("chrome")},
     {Settings::Environment::Chromium, QStringLiteral("chromium")},
@@ -41,30 +44,36 @@ const QMap<Settings::Environment, EnvironmentDescription> Settings::environmentD
     {Settings::Environment::Chrome, {
         QStringLiteral("google-chrome"),
         QStringLiteral("Google Chrome"),
+        QStringLiteral("google-chrome"),
         QStringLiteral("google.com"),
         QStringLiteral("Google")
     } },
     {Settings::Environment::Chromium, {
         QStringLiteral("chromium-browser"),
         QStringLiteral("Chromium"),
+        QStringLiteral("chromium-browser"),
         QStringLiteral("google.com"),
         QStringLiteral("Google")
     } },
     {Settings::Environment::Firefox, {
         QStringLiteral("firefox"),
         QStringLiteral("Mozilla Firefox"),
+        QStringLiteral("firefox"),
         QStringLiteral("mozilla.org"),
         QStringLiteral("Mozilla")
     } },
     {Settings::Environment::Opera, {
         QStringLiteral("opera"),
         QStringLiteral("Opera"),
+        QStringLiteral("opera"),
         QStringLiteral("opera.com"),
         QStringLiteral("Opera")
     } },
     {Settings::Environment::Vivaldi, {
         QStringLiteral("vivaldi"),
         QStringLiteral("Vivaldi"),
+        // This is what the official package on their website uses
+        QStringLiteral("vivaldi-stable"),
         QStringLiteral("vivaldi.com"),
         QStringLiteral("Vivaldi")
     } }
@@ -88,6 +97,31 @@ void Settings::handleData(const QString &event, const QJsonObject &data)
 {
     if (event == QLatin1String("changed")) {
         m_settings = data;
+
+        for (auto it = data.begin(), end = data.end(); it != end; ++it) {
+            const QString &subsystem = it.key();
+            const QJsonObject &settingsObject = it->toObject();
+
+            const QJsonValue enabledVariant = settingsObject.value(QStringLiteral("enabled"));
+            // probably protocol overhead, not a plugin setting, skip.
+            if (enabledVariant.type() == QJsonValue::Undefined) {
+                continue;
+            }
+
+            auto *plugin = PluginManager::self().pluginForSubsystem(subsystem);
+            if (!plugin) {
+                continue;
+            }
+
+            if (enabledVariant.toBool()) {
+                PluginManager::self().loadPlugin(plugin);
+            } else {
+                PluginManager::self().unloadPlugin(plugin);
+            }
+
+            PluginManager::self().settingsChanged(plugin, settingsObject);
+        }
+
         emit changed(data);
     } else if (event == QLatin1String("openKRunnerSettings")) {
         QProcess::startDetached(QStringLiteral("kcmshell5"), {QStringLiteral("kcm_plasmasearch")});
@@ -98,11 +132,37 @@ void Settings::handleData(const QString &event, const QJsonObject &data)
 
         qApp->setApplicationName(m_currentEnvironment.applicationName);
         qApp->setApplicationDisplayName(m_currentEnvironment.applicationDisplayName);
+        qApp->setDesktopFileName(m_currentEnvironment.desktopFileName);
         qApp->setOrganizationDomain(m_currentEnvironment.organizationDomain);
         qApp->setOrganizationName(m_currentEnvironment.organizationName);
     }
 }
 
+QJsonObject Settings::handleData(int serial, const QString &event, const QJsonObject &data)
+{
+    Q_UNUSED(serial)
+    Q_UNUSED(data)
+
+    QJsonObject ret;
+
+    if (event == QLatin1String("getSubsystemStatus")) {
+       // should we add a PluginManager::knownSubsystems() that returns a QList<AbstractBrowserPlugin*>?
+       const QStringList subsystems = PluginManager::self().knownPluginSubsystems();
+       for (const QString &subsystem : subsystems) {
+           const AbstractBrowserPlugin *plugin = PluginManager::self().pluginForSubsystem(subsystem);
+           QJsonObject details{
+               {QStringLiteral("version"), plugin->protocolVersion()},
+               {QStringLiteral("loaded"), plugin->isLoaded()}
+           };
+           ret.insert(subsystem, details);
+        }
+    } else if (event == QLatin1String("getVersion")) {
+        ret.insert(QStringLiteral("host"), QStringLiteral(HOST_VERSION_STRING));
+    }
+
+    return ret;
+}
+
 Settings::Environment Settings::environment() const
 {
     return m_environment;
